<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>FacebookDepreceatedMessage</name>
    <message>
        <source>Facebook XMPP support is disabled since 01.05.2015. This means Kadu will be no longer able to connect to Facebook accounts. You can leave your Facebook accounts configured for chat history or you can remove them from Kadu using Your Account dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu - Facebook</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GTalkProtocolFactory</name>
    <message>
        <source>Gmail/Google Talk ID:</source>
        <translation>Gmail/Google Talk ID:</translation>
    </message>
</context>
<context>
    <name>JabberActions</name>
    <message>
        <source>Resend Subscription</source>
        <translation>Yeniden Abonelik Gönder</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Abonelik Kaldır</translation>
    </message>
    <message>
        <source>Ask for Subscription</source>
        <translation>Abonelik için Sor</translation>
    </message>
</context>
<context>
    <name>JabberAddAccountWidget</name>
    <message>
        <source>&lt;a href=&apos;#&apos;&gt;What is my username?&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;#&apos;&gt;Benim kullanıcı adım ne?&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifre</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Şifremi Hatırla</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Hesap Kimliği</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Bu hesapla ilişkili kimliği girin veya seçin.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Hesap Ekle</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>JabberChangePassword</name>
    <message>
        <source>Current connection is not safe for password change. Use encrypted connection or change password on provider&apos;s site.</source>
        <translation>Şimdiki bağlantınız şifre değiştirmek için güvenli değil. Şifreli bağlantı kullanın veya sağlayıcı sitesinden şifrenizi değiştirin.</translation>
    </message>
    <message>
        <source>Password change is not allowed.</source>
        <translation>Şifre değiştirilmesine izin verilmiyor</translation>
    </message>
</context>
<context>
    <name>JabberChangePasswordWindow</name>
    <message>
        <source>Change Password</source>
        <translation>Şifre Değiştir</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Yeni şifre</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter new password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;XMPP/Jabber hesabınız için yeni şifrenizi girin.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Retype new password</source>
        <translation>Yeni şifreyi tekrar yazın</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Changing password was successful.</source>
        <translation>Şifre değiştirme başarılı.</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;Password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Gerekli alanlara hatalı veri girildi.

Girilen şifre alanları (&quot;Şifre&quot; ve &quot;Şifreyi tekrar yazın&quot;) aynı olmalı!</translation>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>Giriş yapmadan önce şifreyi değiştir.</translation>
    </message>
    <message>
        <source>Password change failed.

Error: %1</source>
        <translation>Şifre değiştirme başarısız.

Hata:%1</translation>
    </message>
</context>
<context>
    <name>JabberContactPersonalInfoWidget</name>
    <message>
        <source>Full Name</source>
        <translation>Tam İsim</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Aile İsmi</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Takma Ad</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Doğum tarihi</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Şehir</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
</context>
<context>
    <name>JabberCreateAccountWidget</name>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifre</translation>
    </message>
    <message>
        <source>Retype Password</source>
        <translation>Şifreyi tekrar yazın</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Şifremi hatırla</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Hesap Kimliği</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Bu hesapla ilişkili kimliği girin veya seçin.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Hesap Kayıt Et</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;New password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation>Gerekli alanlara hatalı veri girildi.

Girilen şifre alanları (&quot;Şifre&quot; ve &quot;Şifreyi tekrar yazın&quot;) aynı olmalı!</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Some servers require your e-mail address during registration.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Bazı sunucular kayıt sırasında e-posta adresi gerektirir.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
</context>
<context>
    <name>JabberEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Hesabı sil</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifre</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Şifremi hatırla</translation>
    </message>
    <message>
        <source>Change your password</source>
        <translation>Şifrenizi değiştirin</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Hesap Kimliği</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Bu hesapla ilişkili kimliği girin veya seçin.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Personal Information</source>
        <translation>Kişisel Bilgiler</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Bağlantı</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Hiç bir zaman</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Her zaman</translation>
    </message>
    <message>
        <source>When available</source>
        <translation>Mümkün olduğunda</translation>
    </message>
    <message>
        <source>Allow plaintext authentication</source>
        <translation>Düz metin kimlik doğrulamasına izin ver</translation>
    </message>
    <message>
        <source>Over encrypted connection</source>
        <translation>Şifreli bağlantı üzerinden</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Resource</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Öncelik</translation>
    </message>
    <message>
        <source>Data transfer proxy</source>
        <translation>Veri aktarımı proxy</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Hesabı kaldır</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation>Proxy ayarı</translation>
    </message>
    <message>
        <source>Publish system information</source>
        <translation>Sistem bilgisi yayımla</translation>
    </message>
    <message>
        <source>XMPP Server</source>
        <translation>XMPP Sunucu</translation>
    </message>
    <message>
        <source>Use custom server address/port</source>
        <translation>Özel sunucu adresi/portu kullan</translation>
    </message>
    <message>
        <source>Server address</source>
        <translation>Sunucu adresi</translation>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation>Şifreli bağlantı kullan</translation>
    </message>
    <message>
        <source>Only in older version</source>
        <translation>Sadece eski versiyonda</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Use computer name as a resource</source>
        <translation>Bilgisayar adını bir kaynak olarak kullan</translation>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation>Yazma olaylarını etkinleştirin</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation>Konuştuğunuz kişi siz mesajı yazarken, göndermeden önce ve tam tersi durumda uyarılacaktır.</translation>
    </message>
    <message>
        <source>Enable chat activity events</source>
        <translation>Konuşma etkinliği olaylarını etkinleştirin</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you suspend or end conversation. And vice versa.</source>
        <translation>Konuştuğunuz kişi askıya aldığınızda, konuşmayı bitirdiğinizde veya tam tersi durumda uyarılacaktır.</translation>
    </message>
    <message>
        <source>Others can see your system name/version</source>
        <translation>Diğerleri sizin sistem adınızı/versiyonunu görebilir</translation>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation>Hesap Kaldırma Onayı</translation>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation>%1 (%2) hesabını kaldırmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>Require data transfer proxy:</source>
        <translation>Gerekli veri aktarımı proxy:</translation>
    </message>
    <message>
        <source>Log in before changing password.</source>
        <translation>Giriş yapmadan önce şifreyi değiştir.</translation>
    </message>
</context>
<context>
    <name>JabberErrorService</name>
    <message>
        <source>Socket error: %1</source>
        <translation>Soket hatası: %1</translation>
    </message>
    <message>
        <source>Server did not respond for PING message</source>
        <translation>Sunucu PING mesajına yanıt vermedi</translation>
    </message>
    <message>
        <source>Unknown error: %1/%2</source>
        <translation>Bilinmeyen hata: %1/%2</translation>
    </message>
    <message>
        <source>Bad request</source>
        <translation>Kötü istek</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Çakışma</translation>
    </message>
    <message>
        <source>Feature not implemented</source>
        <translation>Özellik uygulanmadı</translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation>Yasak</translation>
    </message>
    <message>
        <source>Gone</source>
        <translation>Gitmiş</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>İç Sunucu Hatası</translation>
    </message>
    <message>
        <source>Item not found</source>
        <translation>Nesne bulunamadı</translation>
    </message>
    <message>
        <source>Jid malformed</source>
        <translation>JID hatalı</translation>
    </message>
    <message>
        <source>Not acceptable</source>
        <translation>Kabul edilemez</translation>
    </message>
    <message>
        <source>Not allowed</source>
        <translation>İzin verilmedi</translation>
    </message>
    <message>
        <source>Not authorized</source>
        <translation>Yetkili değil</translation>
    </message>
    <message>
        <source>Payment required</source>
        <translation>Ödeme gerekli</translation>
    </message>
    <message>
        <source>Recipient unavailable</source>
        <translation>Alıcı mevcut değil</translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation>Yönlendiriliyor</translation>
    </message>
    <message>
        <source>Registration required</source>
        <translation>Kayıt işlemi gerekli</translation>
    </message>
    <message>
        <source>Remote server not found</source>
        <translation>Uzak sunucu bulunamadı</translation>
    </message>
    <message>
        <source>Remove server timeout</source>
        <translation>Uzak sunucu zaman aşımı</translation>
    </message>
    <message>
        <source>Resource constraint</source>
        <translation>Kaynak kısıtı</translation>
    </message>
    <message>
        <source>Service unavailable</source>
        <translation>Servis kullanım dışı</translation>
    </message>
    <message>
        <source>Subscription required</source>
        <translation>Abonelik gerekli</translation>
    </message>
    <message>
        <source>Undefined condition</source>
        <translation>Tanımsız durum</translation>
    </message>
    <message>
        <source>Unexpected request</source>
        <translation>Beklenmeyen istek</translation>
    </message>
</context>
<context>
    <name>JabberOutgoingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>İptal edildi</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Dosya bozulmuş</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Protokol hatası</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
</context>
<context>
    <name>JabberPersonalInfoWidget</name>
    <message>
        <source>Full name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Takma isim</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Aile adı</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Doğum yılı</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Şehir</translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation>E-Mail</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
</context>
<context>
    <name>JabberProtocol</name>
    <message>
        <source>Another client connected on the same resource.</source>
        <translation>Aynı kaynakla farklı bir istemci bağlandı.</translation>
    </message>
</context>
<context>
    <name>JabberProtocolFactory</name>
    <message>
        <source>User JID:</source>
        <translation>Kullanıcı JID:</translation>
    </message>
</context>
<context>
    <name>JabberRegisterAccount</name>
    <message>
        <source>Internal error: invalid state</source>
        <translation>İç hata: geçersiz durum</translation>
    </message>
    <message>
        <source>Connection established.</source>
        <translation>
Bağlantı kuruldu.</translation>
    </message>
    <message>
        <source>Negotiating registration parameters.</source>
        <translation>Müzakere kayıt parametreleri.</translation>
    </message>
    <message>
        <source>User with this username is already registered.</source>
        <translation>Kullanıcı zaten bu kullanıcı adıyla kayıtlı.</translation>
    </message>
    <message>
        <source>Registration parameters received.</source>
        <translation>Kayıt parametreleri alındı.</translation>
    </message>
    <message>
        <source>Registration at this server requires XMPP Data Forms support. Kadu currently does not support XMPP Data Forms.</source>
        <translation>Bu sunucudaki kayıt için XMPP Data Forms desteği gereklidir. Kadu şuan XMPP Data Forms desteklemiyor.</translation>
    </message>
    <message>
        <source>%1

Server message: %2</source>
        <translation>%1

Sunucu mesajı: %2</translation>
    </message>
    <message>
        <source>Unknown error: received stanza type %1</source>
        <translation>Bilinmeyen hata: alınan dörtlük tipi %1</translation>
    </message>
    <message>
        <source>SSL certificate rejected</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>JabberStreamIncomingFileTransferHandler</name>
    <message>
        <source>Aborted</source>
        <translation>İptal edildi</translation>
    </message>
    <message>
        <source>File is corrupted</source>
        <translation>Dosya bozulmuş</translation>
    </message>
    <message>
        <source>Protocol error</source>
        <translation>Protokol hatası</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Bilinmeyen hata</translation>
    </message>
</context>
<context>
    <name>JabberWaitForAccountRegisterWindow</name>
    <message>
        <source>Registration was successful. Your new XMPP username is %1.
Store it in a safe place along with the password.
Now please add your friends to the buddy list.</source>
        <translation>Kayınıdınız başarıyla oluşturuldu. Yeni XMPP kullanıcı adınız %1.
Şifrenizi güvenli bir yerde saklayınız.
Lütfen şimdi arkadaş listenize arkadaşlarınızı ekleyin.</translation>
    </message>
    <message>
        <source>Registering new XMPP account</source>
        <translation>Yeni XMPP hesabı kayıt ediliyor</translation>
    </message>
    <message>
        <source>Registration failed.

Server message: %1</source>
        <translation>Kayıt başarısız.

Sunucu mesajı: %1</translation>
    </message>
    <message>
        <source>Connecting with server.</source>
        <translation>Sunucuya bağlanılıyor.</translation>
    </message>
</context>
<context>
    <name>ShowXmlConsoleActionDescription</name>
    <message>
        <source>Show XML Console</source>
        <translation>XML Konsolunu Göster</translation>
    </message>
</context>
<context>
    <name>XmlConsole</name>
    <message>
        <source>XML Console - %1</source>
        <translation>XML Konsolu - %1</translation>
    </message>
</context>
</TS>